Constructor for point layer aesthetics. Used for observed data points and central tendency points across all plot types.
See also
Other element constructors:
pmx_color(),
pmx_errorbar(),
pmx_line(),
pmx_ribbon(),
pmx_style(),
pmx_trend()
Constructor for point layer aesthetics. Used for observed data points and central tendency points across all plot types.
Other element constructors:
pmx_color(),
pmx_errorbar(),
pmx_line(),
pmx_ribbon(),
pmx_style(),
pmx_trend()